@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2017 Montel Laurent <montel@kde.org>
+  Copyright (C) 2017-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +21,7 @@
 
 #include <QObject>
 #include "pimcommon_export.h"
-namespace PimCommon
-{
+namespace PimCommon {
 class LogActivitiesManagerPrivate;
 class PIMCOMMON_EXPORT LogActivitiesManager : public QObject
 {
@@ -34,7 +34,7 @@ public:
 
     void appendLog(const QString &str);
 
-    QString log() const;
+    Q_REQUIRED_RESULT QString log() const;
 
     void clear();
 
